![CI](https://github.com/jackcizon/dsa/actions/workflows/ci.yaml/badge.svg)

# DSA

collections of data structures and algorithms for learning purposes, with 100% test coverage.

## Notes

see license in `LICENSE.txt`

## Version

**2.2.0**
